summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--arch/arm/Kconfig12
-rw-r--r--board/freescale/mx6ul_14x14_ddr3_arm2/Kconfig (renamed from board/freescale/mx6ul_ddr3_arm2/Kconfig)6
-rw-r--r--board/freescale/mx6ul_14x14_ddr3_arm2/Makefile (renamed from board/freescale/mx6ulevk/Makefile)2
-rw-r--r--board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg (renamed from board/freescale/mx6ul_ddr3_arm2/imximage.cfg)0
-rw-r--r--board/freescale/mx6ul_14x14_ddr3_arm2/mx6ul_14x14_ddr3_arm2.c (renamed from board/freescale/mx6ul_ddr3_arm2/mx6ul_ddr3_arm2.c)2
-rw-r--r--board/freescale/mx6ul_14x14_ddr3_arm2/plugin.S (renamed from board/freescale/mx6ul_ddr3_arm2/plugin.S)0
-rw-r--r--board/freescale/mx6ul_14x14_evk/Kconfig (renamed from board/freescale/mx6ulevk/Kconfig)6
-rw-r--r--board/freescale/mx6ul_14x14_evk/MAINTAINERS (renamed from board/freescale/mx6ulevk/MAINTAINERS)0
-rw-r--r--board/freescale/mx6ul_14x14_evk/Makefile (renamed from board/freescale/mx6ul_ddr3_arm2/Makefile)2
-rw-r--r--board/freescale/mx6ul_14x14_evk/imximage.cfg (renamed from board/freescale/mx6ulevk/imximage.cfg)0
-rw-r--r--board/freescale/mx6ul_14x14_evk/mx6ul_14x14_evk.c (renamed from board/freescale/mx6ulevk/mx6ulevk.c)2
-rw-r--r--board/freescale/mx6ul_14x14_evk/plugin.S (renamed from board/freescale/mx6ulevk/plugin.S)0
-rw-r--r--configs/mx6ul_14x14_ddr3_arm2_defconfig7
-rw-r--r--configs/mx6ul_14x14_ddr3_arm2_eimnor_defconfig7
-rw-r--r--configs/mx6ul_14x14_ddr3_arm2_nand_defconfig7
-rw-r--r--configs/mx6ul_14x14_ddr3_arm2_qspi1_defconfig7
-rw-r--r--configs/mx6ul_14x14_ddr3_arm2_spinor_defconfig7
-rw-r--r--configs/mx6ul_14x14_evk_android_defconfig5
-rw-r--r--configs/mx6ul_14x14_evk_defconfig5
-rw-r--r--configs/mx6ul_14x14_evk_qspi1_defconfig5
-rw-r--r--configs/mx6ul_ddr3_arm2_defconfig7
-rw-r--r--configs/mx6ul_ddr3_arm2_eimnor_defconfig7
-rw-r--r--configs/mx6ul_ddr3_arm2_nand_defconfig7
-rw-r--r--configs/mx6ul_ddr3_arm2_qspi1_defconfig7
-rw-r--r--configs/mx6ul_ddr3_arm2_spinor_defconfig7
-rw-r--r--configs/mx6ulevk_defconfig5
-rw-r--r--configs/mx6ulevk_qspi1_defconfig5
-rw-r--r--configs/mx6ulevkandroid_defconfig5
-rw-r--r--include/configs/mx6ul_14x14_ddr3_arm2.h (renamed from include/configs/mx6ul_ddr3_arm2.h)8
-rw-r--r--include/configs/mx6ul_14x14_evk.h (renamed from include/configs/mx6ulevk.h)10
-rw-r--r--include/configs/mx6ul_14x14_evk_android.h (renamed from include/configs/mx6ulevkandroid.h)0
31 files changed, 75 insertions, 75 deletions
diff --git a/arch/arm/Kconfig b/arch/arm/Kconfig
index 426d6a03a0..e62f1b7526 100644
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -568,12 +568,12 @@ config TARGET_MX7DSABRESD
bool "Support mx7dsabresd"
select CPU_V7
-config TARGET_MX6ULEVK
- bool "Support mx6ulevk"
+config TARGET_MX6UL_14X14_EVK
+ bool "Support mx6ul_14x14_evk"
select CPU_V7
-config TARGET_MX6UL_DDR3_ARM2
- bool "Support mx6ul_ddr3_arm2"
+config TARGET_MX6UL_14X14_DDR3_ARM2
+ bool "Support mx6ul_14x14_ddr3_arm2"
select CPU_V7
config TARGET_GW_VENTANA
@@ -880,8 +880,8 @@ source "board/freescale/mx7d_12x12_lpddr3_arm2/Kconfig"
source "board/freescale/mx7d_19x19_lpddr3_arm2/Kconfig"
source "board/freescale/mx7d_19x19_ddr3_arm2/Kconfig"
source "board/freescale/mx7dsabresd/Kconfig"
-source "board/freescale/mx6ulevk/Kconfig"
-source "board/freescale/mx6ul_ddr3_arm2/Kconfig"
+source "board/freescale/mx6ul_14x14_evk/Kconfig"
+source "board/freescale/mx6ul_14x14_ddr3_arm2/Kconfig"
source "board/freescale/vf610twr/Kconfig"
source "board/gateworks/gw_ventana/Kconfig"
source "board/genesi/mx51_efikamx/Kconfig"
diff --git a/board/freescale/mx6ul_ddr3_arm2/Kconfig b/board/freescale/mx6ul_14x14_ddr3_arm2/Kconfig
index d4fe742076..c7d15bd6b5 100644
--- a/board/freescale/mx6ul_ddr3_arm2/Kconfig
+++ b/board/freescale/mx6ul_14x14_ddr3_arm2/Kconfig
@@ -1,7 +1,7 @@
-if TARGET_MX6UL_DDR3_ARM2
+if TARGET_MX6UL_14X14_DDR3_ARM2
config SYS_BOARD
- default "mx6ul_ddr3_arm2"
+ default "mx6ul_14x14_ddr3_arm2"
config SYS_VENDOR
default "freescale"
@@ -10,6 +10,6 @@ config SYS_SOC
default "mx6"
config SYS_CONFIG_NAME
- default "mx6ul_ddr3_arm2"
+ default "mx6ul_14x14_ddr3_arm2"
endif
diff --git a/board/freescale/mx6ulevk/Makefile b/board/freescale/mx6ul_14x14_ddr3_arm2/Makefile
index 23f5d806ed..bf63d54ce6 100644
--- a/board/freescale/mx6ulevk/Makefile
+++ b/board/freescale/mx6ul_14x14_ddr3_arm2/Makefile
@@ -3,7 +3,7 @@
# SPDX-License-Identifier: GPL-2.0+
#
-obj-y := mx6ulevk.o
+obj-y := mx6ul_14x14_ddr3_arm2.o
extra-$(CONFIG_USE_PLUGIN) := plugin.bin
$(obj)/plugin.bin: $(obj)/plugin.o
diff --git a/board/freescale/mx6ul_ddr3_arm2/imximage.cfg b/board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg
index 87c4eaa222..87c4eaa222 100644
--- a/board/freescale/mx6ul_ddr3_arm2/imximage.cfg
+++ b/board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg
diff --git a/board/freescale/mx6ul_ddr3_arm2/mx6ul_ddr3_arm2.c b/board/freescale/mx6ul_14x14_ddr3_arm2/mx6ul_14x14_ddr3_arm2.c
index e2cc28e3a9..057a580c06 100644
--- a/board/freescale/mx6ul_ddr3_arm2/mx6ul_ddr3_arm2.c
+++ b/board/freescale/mx6ul_14x14_ddr3_arm2/mx6ul_14x14_ddr3_arm2.c
@@ -964,7 +964,7 @@ u32 get_board_rev(void)
int checkboard(void)
{
- puts("Board: MX6UL DDR3 ARM2\n");
+ puts("Board: MX6UL 14X14 DDR3 ARM2\n");
return 0;
}
diff --git a/board/freescale/mx6ul_ddr3_arm2/plugin.S b/board/freescale/mx6ul_14x14_ddr3_arm2/plugin.S
index 3ce00dadb9..3ce00dadb9 100644
--- a/board/freescale/mx6ul_ddr3_arm2/plugin.S
+++ b/board/freescale/mx6ul_14x14_ddr3_arm2/plugin.S
diff --git a/board/freescale/mx6ulevk/Kconfig b/board/freescale/mx6ul_14x14_evk/Kconfig
index 8b0b9d49a6..393aca629b 100644
--- a/board/freescale/mx6ulevk/Kconfig
+++ b/board/freescale/mx6ul_14x14_evk/Kconfig
@@ -1,7 +1,7 @@
-if TARGET_MX6ULEVK
+if TARGET_MX6UL_14X14_EVK
config SYS_BOARD
- default "mx6ulevk"
+ default "mx6ul_14x14_evk"
config SYS_VENDOR
default "freescale"
@@ -10,6 +10,6 @@ config SYS_SOC
default "mx6"
config SYS_CONFIG_NAME
- default "mx6ulevk"
+ default "mx6ul_14x14_evk"
endif
diff --git a/board/freescale/mx6ulevk/MAINTAINERS b/board/freescale/mx6ul_14x14_evk/MAINTAINERS
index fe651535d5..fe651535d5 100644
--- a/board/freescale/mx6ulevk/MAINTAINERS
+++ b/board/freescale/mx6ul_14x14_evk/MAINTAINERS
diff --git a/board/freescale/mx6ul_ddr3_arm2/Makefile b/board/freescale/mx6ul_14x14_evk/Makefile
index 992d847a99..393dc1302c 100644
--- a/board/freescale/mx6ul_ddr3_arm2/Makefile
+++ b/board/freescale/mx6ul_14x14_evk/Makefile
@@ -3,7 +3,7 @@
# SPDX-License-Identifier: GPL-2.0+
#
-obj-y := mx6ul_ddr3_arm2.o
+obj-y := mx6ul_14x14_evk.o
extra-$(CONFIG_USE_PLUGIN) := plugin.bin
$(obj)/plugin.bin: $(obj)/plugin.o
diff --git a/board/freescale/mx6ulevk/imximage.cfg b/board/freescale/mx6ul_14x14_evk/imximage.cfg
index 2af4d86a0b..2af4d86a0b 100644
--- a/board/freescale/mx6ulevk/imximage.cfg
+++ b/board/freescale/mx6ul_14x14_evk/imximage.cfg
diff --git a/board/freescale/mx6ulevk/mx6ulevk.c b/board/freescale/mx6ul_14x14_evk/mx6ul_14x14_evk.c
index 6b1370e218..10e9a35998 100644
--- a/board/freescale/mx6ulevk/mx6ulevk.c
+++ b/board/freescale/mx6ul_14x14_evk/mx6ul_14x14_evk.c
@@ -880,7 +880,7 @@ u32 get_board_rev(void)
int checkboard(void)
{
- puts("Board: MX6UL EVK\n");
+ puts("Board: MX6UL 14x14 EVK\n");
return 0;
}
diff --git a/board/freescale/mx6ulevk/plugin.S b/board/freescale/mx6ul_14x14_evk/plugin.S
index 13b696368d..13b696368d 100644
--- a/board/freescale/mx6ulevk/plugin.S
+++ b/board/freescale/mx6ul_14x14_evk/plugin.S
diff --git a/configs/mx6ul_14x14_ddr3_arm2_defconfig b/configs/mx6ul_14x14_ddr3_arm2_defconfig
new file mode 100644
index 0000000000..0828836f95
--- /dev/null
+++ b/configs/mx6ul_14x14_ddr3_arm2_defconfig
@@ -0,0 +1,7 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg,MX6UL"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_DDR3_ARM2=y
+CONFIG_SYS_MALLOC_F=y
+CONFIG_SYS_MALLOC_F_LEN=0x400
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_ddr3_arm2_eimnor_defconfig b/configs/mx6ul_14x14_ddr3_arm2_eimnor_defconfig
new file mode 100644
index 0000000000..686f05ce0c
--- /dev/null
+++ b/configs/mx6ul_14x14_ddr3_arm2_eimnor_defconfig
@@ -0,0 +1,7 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_EIMNOR"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_DDR3_ARM2=y
+CONFIG_SYS_MALLOC_F=y
+CONFIG_SYS_MALLOC_F_LEN=0x400
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_ddr3_arm2_nand_defconfig b/configs/mx6ul_14x14_ddr3_arm2_nand_defconfig
new file mode 100644
index 0000000000..71fdbd4515
--- /dev/null
+++ b/configs/mx6ul_14x14_ddr3_arm2_nand_defconfig
@@ -0,0 +1,7 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_NAND"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_DDR3_ARM2=y
+CONFIG_SYS_MALLOC_F=y
+CONFIG_SYS_MALLOC_F_LEN=0x400
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_ddr3_arm2_qspi1_defconfig b/configs/mx6ul_14x14_ddr3_arm2_qspi1_defconfig
new file mode 100644
index 0000000000..d89376237b
--- /dev/null
+++ b/configs/mx6ul_14x14_ddr3_arm2_qspi1_defconfig
@@ -0,0 +1,7 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_QSPI"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_DDR3_ARM2=y
+CONFIG_SYS_MALLOC_F=y
+CONFIG_SYS_MALLOC_F_LEN=0x400
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_ddr3_arm2_spinor_defconfig b/configs/mx6ul_14x14_ddr3_arm2_spinor_defconfig
new file mode 100644
index 0000000000..f137e01093
--- /dev/null
+++ b/configs/mx6ul_14x14_ddr3_arm2_spinor_defconfig
@@ -0,0 +1,7 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_SPINOR"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_DDR3_ARM2=y
+CONFIG_SYS_MALLOC_F=y
+CONFIG_SYS_MALLOC_F_LEN=0x400
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_evk_android_defconfig b/configs/mx6ul_14x14_evk_android_defconfig
new file mode 100644
index 0000000000..53f39d5521
--- /dev/null
+++ b/configs/mx6ul_14x14_evk_android_defconfig
@@ -0,0 +1,5 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_evk/imximage.cfg,MX6UL,ANDROID_SUPPORT"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_EVK=y
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_evk_defconfig b/configs/mx6ul_14x14_evk_defconfig
new file mode 100644
index 0000000000..98d01c6fcd
--- /dev/null
+++ b/configs/mx6ul_14x14_evk_defconfig
@@ -0,0 +1,5 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_evk/imximage.cfg,MX6UL"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_EVK=y
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_14x14_evk_qspi1_defconfig b/configs/mx6ul_14x14_evk_qspi1_defconfig
new file mode 100644
index 0000000000..6344e88f5f
--- /dev/null
+++ b/configs/mx6ul_14x14_evk_qspi1_defconfig
@@ -0,0 +1,5 @@
+CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_14x14_evk/imximage.cfg,MX6UL,SYS_BOOT_QSPI"
+CONFIG_ARM=y
+CONFIG_TARGET_MX6UL_14X14_EVK=y
+CONFIG_DM=y
+CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_ddr3_arm2_defconfig b/configs/mx6ul_ddr3_arm2_defconfig
deleted file mode 100644
index 8903a45de1..0000000000
--- a/configs/mx6ul_ddr3_arm2_defconfig
+++ /dev/null
@@ -1,7 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_ddr3_arm2/imximage.cfg,MX6UL"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6UL_DDR3_ARM2=y
-CONFIG_SYS_MALLOC_F=y
-CONFIG_SYS_MALLOC_F_LEN=0x400
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_ddr3_arm2_eimnor_defconfig b/configs/mx6ul_ddr3_arm2_eimnor_defconfig
deleted file mode 100644
index ba65814cf7..0000000000
--- a/configs/mx6ul_ddr3_arm2_eimnor_defconfig
+++ /dev/null
@@ -1,7 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_EIMNOR"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6UL_DDR3_ARM2=y
-CONFIG_SYS_MALLOC_F=y
-CONFIG_SYS_MALLOC_F_LEN=0x400
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_ddr3_arm2_nand_defconfig b/configs/mx6ul_ddr3_arm2_nand_defconfig
deleted file mode 100644
index 0d31e696bf..0000000000
--- a/configs/mx6ul_ddr3_arm2_nand_defconfig
+++ /dev/null
@@ -1,7 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_NAND"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6UL_DDR3_ARM2=y
-CONFIG_SYS_MALLOC_F=y
-CONFIG_SYS_MALLOC_F_LEN=0x400
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_ddr3_arm2_qspi1_defconfig b/configs/mx6ul_ddr3_arm2_qspi1_defconfig
deleted file mode 100644
index 1d59f3adde..0000000000
--- a/configs/mx6ul_ddr3_arm2_qspi1_defconfig
+++ /dev/null
@@ -1,7 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_QSPI"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6UL_DDR3_ARM2=y
-CONFIG_SYS_MALLOC_F=y
-CONFIG_SYS_MALLOC_F_LEN=0x400
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ul_ddr3_arm2_spinor_defconfig b/configs/mx6ul_ddr3_arm2_spinor_defconfig
deleted file mode 100644
index 0672e0b851..0000000000
--- a/configs/mx6ul_ddr3_arm2_spinor_defconfig
+++ /dev/null
@@ -1,7 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ul_ddr3_arm2/imximage.cfg,MX6UL,SYS_BOOT_SPINOR"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6UL_DDR3_ARM2=y
-CONFIG_SYS_MALLOC_F=y
-CONFIG_SYS_MALLOC_F_LEN=0x400
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ulevk_defconfig b/configs/mx6ulevk_defconfig
deleted file mode 100644
index 282e86db27..0000000000
--- a/configs/mx6ulevk_defconfig
+++ /dev/null
@@ -1,5 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ulevk/imximage.cfg,MX6UL"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6ULEVK=y
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ulevk_qspi1_defconfig b/configs/mx6ulevk_qspi1_defconfig
deleted file mode 100644
index a826ca5d25..0000000000
--- a/configs/mx6ulevk_qspi1_defconfig
+++ /dev/null
@@ -1,5 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ulevk/imximage.cfg,MX6UL,SYS_BOOT_QSPI"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6ULEVK=y
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/configs/mx6ulevkandroid_defconfig b/configs/mx6ulevkandroid_defconfig
deleted file mode 100644
index 69b241ddd2..0000000000
--- a/configs/mx6ulevkandroid_defconfig
+++ /dev/null
@@ -1,5 +0,0 @@
-CONFIG_SYS_EXTRA_OPTIONS="IMX_CONFIG=board/freescale/mx6ulevk/imximage.cfg,MX6UL,ANDROID_SUPPORT"
-CONFIG_ARM=y
-CONFIG_TARGET_MX6ULEVK=y
-CONFIG_DM=y
-CONFIG_DM_THERMAL=y
diff --git a/include/configs/mx6ul_ddr3_arm2.h b/include/configs/mx6ul_14x14_ddr3_arm2.h
index 318c3c87ca..0148f6c9e6 100644
--- a/include/configs/mx6ul_ddr3_arm2.h
+++ b/include/configs/mx6ul_14x14_ddr3_arm2.h
@@ -1,12 +1,12 @@
/*
* Copyright (C) 2015 Freescale Semiconductor, Inc.
*
- * Configuration settings for the Freescale i.MX7.
+ * Configuration settings for the Freescale i.MX6UL 14x14 DDR3 ARM2.
*
* SPDX-License-Identifier: GPL-2.0+
*/
-#ifndef __MX6UL_DDR3_ARM2_CONFIG_H
-#define __MX6UL_DDR3_ARM2_CONFIG_H
+#ifndef __MX6UL_14X14_DDR3_ARM2_CONFIG_H
+#define __MX6UL_14X14_DDR3_ARM2_CONFIG_H
#include <asm/arch/imx-regs.h>
@@ -165,7 +165,7 @@
"console=ttymxc0\0" \
"fdt_high=0xffffffff\0" \
"initrd_high=0xffffffff\0" \
- "fdt_file=imx6ul-ddr3-arm2.dtb\0" \
+ "fdt_file=imx6ul-14x14-ddr3-arm2.dtb\0" \
"fdt_addr=0x83000000\0" \
"boot_fdt=try\0" \
"ip_dyn=yes\0" \
diff --git a/include/configs/mx6ulevkandroid.h b/include/configs/mx6ul_14x14_evk_android.h
index f44145ab0d..f44145ab0d 100644
--- a/include/configs/mx6ulevkandroid.h
+++ b/include/configs/mx6ul_14x14_evk_android.h
diff --git a/include/configs/mx6ulevk.h b/include/configs/mx6ul_14x14_evk.h
index 4dce52c236..dde1463c38 100644
--- a/include/configs/mx6ulevk.h
+++ b/include/configs/mx6ul_14x14_evk.h
@@ -1,12 +1,12 @@
/*
* Copyright (C) 2015 Freescale Semiconductor, Inc.
*
* Configuration settings for the Freescale i.MX6UL EVK board.
*
* SPDX-License-Identifier: GPL-2.0+
*/
-#ifndef __MX6UL_EVK_CONFIG_H
-#define __MX6UL_EVK_CONFIG_H
+#ifndef __MX6UL_14X14_EVK_CONFIG_H
+#define __MX6UL_14X14_EVK_CONFIG_H
#include <asm/arch/imx-regs.h>
@@ -182,7 +182,7 @@
"console=ttymxc0\0" \
"fdt_high=0xffffffff\0" \
"initrd_high=0xffffffff\0" \
- "fdt_file=imx6ul-evk.dtb\0" \
+ "fdt_file=imx6ul-14x14-evk.dtb\0" \
"fdt_addr=0x83000000\0" \
"boot_fdt=try\0" \
"ip_dyn=yes\0" \
@@ -393,7 +393,7 @@
#endif
#if defined(CONFIG_ANDROID_SUPPORT)
-#include "mx6ulevkandroid.h"
+#include "mx6ul_14x14_evk_android.h"
#endif
#endif
@@ -1,12 +1,12 @@
* Copyright (C) 2015 Freescale Semiconductor, Inc.
*
- * Configuration settings for the Freescale i.MX6UL EVK board.
+ * Configuration settings for the Freescale i.MX6UL 14x14 EVK board.
*
* SPDX-License-Identifier: GPL-2.0+